## 股票回购

接口：repurchase

描述：获取上市公司回购股票数据

积分：用户需要至少600积分才可以调取，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ann_date | str | N | 公告日期（任意填参数，如果都不填，单次默认返回2000条） |
| start_date | str | N | 公告开始日期 |
| end_date | str | N | 公告结束日期 |

以上日期格式为：YYYYMMDD，比如20181010

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | TS代码 |
| ann_date | str | Y | 公告日期 |
| end_date | str | Y | 截止日期 |
| proc | str | Y | 进度 |
| exp_date | str | Y | 过期日期 |
| vol | float | Y | 回购数量 |
| amount | float | Y | 回购金额 |
| high_limit | float | Y | 回购最高价 |
| low_limit | float | Y | 回购最低价 |

接口示例

```python
pro = ts.pro_api()

df = pro.repurchase(ann_date='', start_date='20180101', end_date='20180510')

#取某日
df = pro.repurchase(ann_date='20181010')
```

数据示例

```python
ts_code  ann_date  end_date    proc  exp_date         vol        amount  \
0   300451.SZ  20181010  20181008      完成      None     51900.0  4.498500e+05   
```